@@ -23,11 +23,14 @@ do_RidgePlot <- function(sample,
                          slot = "data",
                          continuous_scale = FALSE,
                          legend.title = NULL,
+                         legend.ncol = NULL,
+                         legend.nrow = NULL,
+                         legend.byrow = FALSE,
                          legend.position = NULL,
                          legend.width = 1,
                          legend.length = 20,
-                         legend.framewidth = 1.5,
-                         legend.tickwidth = 1.5,
+                         legend.framewidth = 0.5,
+                         legend.tickwidth = 0.5,
                          legend.framecolor = "grey50",
                          legend.tickcolor = "white",
                          legend.type = "colorbar",
@@ -65,7 +68,8 @@ do_RidgePlot <- function(sample,
                        "compute_distribution_tails" = compute_distribution_tails,
                        "color_by_probabilities" = color_by_probabilities,
                        "plot.grid" = plot.grid,
-                       "flip" = flip)
+                       "flip" = flip,
+                       "legend.nrow" = legend.nrow)
   check_type(parameters = logical_list, required_type = "logical", test_function = is.logical)
   # Check numeric parameters.
   numeric_list <- list("legend.width" = legend.width,
@@ -76,7 +80,9 @@ do_RidgePlot <- function(sample,
                        "quantiles" = quantiles,
                        "prob_tails" = prob_tails,
                        "viridis_direction" = viridis_direction,
-                       "rotate_x_axis_labels" = rotate_x_axis_labels)
+                       "rotate_x_axis_labels" = rotate_x_axis_labels,
+                       "legend.ncol" = legend.ncol,
+                       "legend.nrow" = legend.nrow)
   check_type(parameters = numeric_list, required_type = "numeric", test_function = is.numeric)
   # Check character parameters.
   character_list <- list("feature" = feature,
@@ -128,7 +134,7 @@ do_RidgePlot <- function(sample,
       p <- data %>%
            ggplot2::ggplot(mapping = ggplot2::aes(x = .data$feature,
                                                   y = .data$group.by,
-                                                  fill = ..x..)) +
+                                                  fill = ggplot2::after_stat(x))) +
            ggridges::geom_density_ridges_gradient(color = "black",
                                                   size = 1.25) +
            ggplot2::scale_fill_viridis_c(option = viridis_color_map,
@@ -161,7 +167,7 @@ do_RidgePlot <- function(sample,
         p <- data %>%
              ggplot2::ggplot(mapping = ggplot2::aes(x = .data$feature,
                                                     y = .data$group.by,
-                                                    fill = ..quantile..)) +
+                                                    fill = ggplot2::after_stat(quantile))) +
              ggridges::stat_density_ridges(color = "black",
                                            size = 1.25,
                                            quantile_lines = TRUE,
@@ -170,12 +176,18 @@ do_RidgePlot <- function(sample,
                                            quantiles = quantiles) +
              ggplot2::scale_fill_manual(values = viridis::viridis(n = length(quantiles) + 1, option = viridis_color_map, direction = viridis_direction),
                                         name = ifelse(is.null(legend.title), "Probability", legend.title),
-                                        labels = unique(labels))
+                                        labels = unique(labels)) +
+             ggplot2::guides(fill = ggplot2::guide_legend(title = ifelse(is.null(legend.title), "Probability", legend.title),
+                                                          title.position = "top",
+                                                          title.hjust = 0.5,
+                                                          ncol = legend.ncol,
+                                                          nrow = legend.nrow,
+                                                          byrow = legend.byrow))
       } else if (isTRUE(compute_distribution_tails)){
         p <- data %>%
              ggplot2::ggplot(mapping = ggplot2::aes(x = .data$feature,
                                                     y = .data$group.by,
-                                                    fill = ..quantile..)) +
+                                                    fill = ggplot2::after_stat(quantile))) +
              ggridges::stat_density_ridges(color = "black",
                                            size = 1.25,
                                            quantile_lines = TRUE,
@@ -186,12 +198,16 @@ do_RidgePlot <- function(sample,
                                         labels = c(paste0("]0 , ", 0 + prob_tails, "]"),
                                                    paste0("]", 0 + prob_tails, ", ",  1 - prob_tails, "]"),
                                                    paste0("]", 1 - prob_tails, ", 1]")),
-                                        name = ifelse(is.null(legend.title), "Probability", legend.title))
+                                        name = ifelse(is.null(legend.title), "Probability", legend.title))  +
+             ggplot2::guides(fill = ggplot2::guide_legend(title = ifelse(is.null(legend.title), "Probability", legend.title),
+                                                          title.position = "top",
+                                                          title.hjust = 0.5,
+                                                          ncol = legend.ncol))
       } else if (isTRUE(color_by_probabilities)){
         p <- data %>%
              ggplot2::ggplot(mapping = ggplot2::aes(x = .data$feature,
                                                     y = .data$group.by,
-                                                    fill = 0.5 - abs(0.5 - ..ecdf..))) +
+                                                    fill = 0.5 - abs(0.5 - ggplot2::after_stat(ecdf)))) +
              ggridges::stat_density_ridges(color = "black",
                                            size = 1.25,
                                            calc_ecdf = TRUE,
@@ -221,7 +237,11 @@ do_RidgePlot <- function(sample,
          ggridges::geom_density_ridges(color = "black",
                                        size = 1.25) +
          ggplot2::scale_fill_manual(values = if (is.null(colors.use)) {generate_color_scale(if (is.null(group.by)){levels(sample)} else {if(is.factor(sample@meta.data[, group.by])){levels(sample@meta.data[, group.by])} else {unique(sample@meta.data[, group.by])}})} else {colors.use},
-                                    name = legend.title)
+                                    name = legend.title) +
+         ggplot2::guides(fill = ggplot2::guide_legend(title = legend.title,
+                                                      title.position = "top",
+                                                      title.hjust = 0.5,
+                                                      ncol = legend.ncol))
   }
 
   if (!is.null(split.by)){
