@@ -1,7 +1,19 @@
 if (isFALSE(dep_check[["do_CorrelationPlot"]])){
+
+  testthat::test_that("do_CorrelationPlot: CRAN essentials", {
+    sample$orig.ident <- ifelse(sample$seurat_clusters %in% c("1", "2"), "A", "B")
+
+    genes <- list("A" = Seurat::VariableFeatures(sample)[1:5],
+                  "B" = Seurat::VariableFeatures(sample)[6:10],
+                  "C" = Seurat::VariableFeatures(sample)[11:15])
+
+    p <- SCpubr::do_CorrelationPlot(sample = sample, legend.position = "top")
+    testthat::expect_true("HeatmapList" %in% class(p))
+  })
+
   testthat::test_that("do_CorrelationPlot: PASS - normal", {
 
-
+    testthat::skip_on_cran()
     sample$orig.ident <- ifelse(sample$seurat_clusters %in% c("1", "2"), "A", "B")
 
     genes <- list("A" = Seurat::VariableFeatures(sample)[1:5],
@@ -16,7 +28,7 @@ if (isFALSE(dep_check[["do_CorrelationPlot"]])){
   })
 
   testthat::test_that("do_CorrelationPlot: PASS - group.by", {
-
+    testthat::skip_on_cran()
 
     sample$orig.ident <- ifelse(sample$seurat_clusters %in% c("1", "2"), "A", "B")
 
@@ -30,7 +42,7 @@ if (isFALSE(dep_check[["do_CorrelationPlot"]])){
   })
 
   testthat::test_that("do_CorrelationPlot: PASS - group.by - rotate axis labels", {
-
+    testthat::skip_on_cran()
 
     sample$orig.ident <- ifelse(sample$seurat_clusters %in% c("1", "2"), "A", "B")
 
@@ -45,7 +57,7 @@ if (isFALSE(dep_check[["do_CorrelationPlot"]])){
   })
 
   testthat::test_that("do_CorrelationPlot: PASS - group.by - cell size", {
-
+    testthat::skip_on_cran()
 
     sample$orig.ident <- ifelse(sample$seurat_clusters %in% c("1", "2"), "A", "B")
 
@@ -64,7 +76,7 @@ if (isFALSE(dep_check[["do_CorrelationPlot"]])){
 
 
   testthat::test_that("do_CorrelationPlot: PASS - row title and column title", {
-
+    testthat::skip_on_cran()
 
     sample$orig.ident <- ifelse(sample$seurat_clusters %in% c("1", "2"), "A", "B")
 
@@ -82,7 +94,7 @@ if (isFALSE(dep_check[["do_CorrelationPlot"]])){
   })
 
   testthat::test_that("do_CorrelationPlot: PASS - group.by factor", {
-
+    testthat::skip_on_cran()
 
     sample$orig.ident <- ifelse(sample$seurat_clusters %in% c("1", "2"), "A", "B")
 
